#
# spec file for package qjackctl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qjackctl
Version:        0.4.0
Release:        5.3
Summary:        Graphical User Interface to Control JACK Servers
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://qjackctl.sf.net
Source:         http://prdownloads.sourceforge.net/qjackctl/qjackctl-%{version}.tar.gz
Patch1:         qjackctl-remove_build_timestamps.patch
Patch2:         qjackctl-remove_absolute_path_from_exec_in_desktop-file.patch
BuildRequires:  alsa-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjack-devel
BuildRequires:  libqt4-devel
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
Requires:       jack
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
JACK Audio Connection Kit - Qt GUI Interface: A simple Qt application
to control the JACK server. Written in C++ around the Qt4 toolkit
for X11, most exclusively using Qt Designer. Provides a simple GUI
dialog for setting several JACK server parameters, which are properly
saved between sessions, and a way control of the status of the audio
server. With time, this primordial interface has become richer by
including a enhanced patchbay and connection control features.

%lang_package

%prep
%setup -q
%patch1
%patch2

# fix up desktop file
sed -i -e'/^X-SuSE-translate/d' src/qjackctl.desktop.in

find . -type f -name '*.pro' | while read pro; do
    echo 'QMAKE_CXXFLAGS="%{optflags}"' >> "$pro"
done

%build
[ -f Makefile.svn ] && make -f Makefile.svn
%configure
%__make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file -r qjackctl Music AudioVideo

L="$PWD/%{name}.lang"; echo -n >"$L"
B="%{_datadir}/qjackctl/translations"
pushd "%{buildroot}${B}"
/bin/ls *.qm | while read qm; do
    l="${qm##*_}"
    l="${l%.qm}"
    echo "%lang($l) ${B}/${qm}" >>"$L"
done
popd

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README TODO
%{_bindir}/qjackctl
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/*/*/apps/%{name}.*
%doc %{_mandir}/man1/qjackctl.1*

%files lang -f %{name}.lang
%defattr(-,root,root)
%dir %{_datadir}/qjackctl
%dir %{_datadir}/qjackctl/translations

%changelog
* Tue Aug 11 2015 stephan.barth@suse.com
- update to version 0.4.0, including version 0.3.13
  Important changes from upstream for version 0.4.0:
  - Most advanced Setup/Settings are moved into new Setup/Advanced settings
    tab; limit range for the real-time priority setting, now having 6 as
    absolute minimum valid value (after patches by Robin Gareus, thanks).
  - A new top-level widget window geometry state save and restore sub-routine
    is now in effect (EXPERIMENTAL)
  - Delayed geometry setup for widget windows upon startup has been deprecated
    and scrapped altogether.
  - Setup/settings dialog tab is going into some layout changes; also got rid
    of old patchbay auto-refresh timer cruft, which was previously
    hidden/disabled.
  - New socket names are now automatically inferred from selected client names
    while on the Patchbay widget, Socket dialog.
  Important changes from upstream for version 0.3.13:
  - Added application description as freedesktop.org's AppData.
  - Setup dialog form is now modeless.
  - Introducing brand new active patchbay reset/disconnect-all user preference
    option.
  - Current highlighted client/port connections are now drawn with thicker
    connector lines.
  - New user preference option on whether to show the nagging 'program will
    keep running in the system tray' message, on main window close.
  - Connections lines now drawn with anti-aliasing; connections splitter
    handles width is now reduced.
  - Drop missing or non-existent patchbay definition files from the most
    recent used list.
* Fri Mar 13 2015 p.drouand@gmail.com
- Update to version 0.3.12
  * JACK client/port pretty-name (metadata) support is being introduced
    and seamlessly integrated with old Connections client/port aliases
    editing (rename) (EXPERIMENTAL)
  * Application close confirm warning is now raising the main window
    as visible and active for due top level display, especially
    applicable when minimized to the system tray.
  * Messages standard output capture has been slightly improved as
    for non-blocking i/o, whenever available.
  * Translations install directory change.
  * Allow the build system to include an user specified LDFLAGS.
  * Missing input/output-latency parameter settings now settled for
    the D-BUS controlled JACK server and firewire back-end driver.
- Recommend the translations subpackage
* Thu Mar  6 2014 stephan.barth@suse.com
- qjackctl-remove_absolute_path_from_exec_in_desktop-file.patch:
  This patch removes the absolute path of the qjackctl binary from the desktop
  file, that is in %%{_datadir}/applications/%%{name}.desktop
  (This was not mentioned in the previous submission)
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 0.3.11:
  * interface device selection is now unified, by moving the old '>' pop-up
    menu into the customized combo-box drop-down list showing all available
    card/device names and descriptions
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 0.3.10:
  * session infra-client management finally being added
  * transport tempo (BPM) precision display fixed to 4 digits
  * color-candy (dang old ANSI terminal?) escape sequences are
    now silently stripped from jackdbus messages captured log
  * list ALSA device card id. string instead of device number,
    while on setup dialog
  * Japanese (ja) translation added
* Fri May 18 2012 pascal.bleser@opensuse.org
- update to 0.3.9:
  * killing D-BUS controlled JACK server is now made optional, cf.
    Setup/Misc/Stop JACK audio server on application exit
  * a new so called "Server Suffix" parameter option appears to rescue on the
    situations where QjackCtl falls short on extra, exquisite and/or esoteric
    command line options eg. (net)jack1/2 differences.
  * fixed D-Bus Input/Output device parameter settings, filled when either
    interface is selected for Capture/Playback only
  * main window is now brought to front and (re)activated when clicking on the
    system tray icon instead of just hiding it
  * add current xrun count to the system tray icon tooltip, if not zero
- added portaudio support
- revamped spec file
- moved translations to -lang package
* Sun Aug  7 2011 mseben@gmail.com
- update to 0.3.8:
  - Debugging stacktrace now applies to all working threads.
  - Session "Save" button now a drop-down menu, replacing the
    session save type combo-box/drop-down list selection. Also,
    an early session directory versioning/numbering scheme is
    now in place, although optional.
  - Probable fix to debian bug report #624198 - segfault when
    pressing the stop button (by Grant Adrian Diffey, after a
    patch from Adrian Knoth, thanks).
  - Desktop environment session shutdown (eg. logout) is now
    tapped for graceful application exit, even though the main
    window is active (visible) and minimizing to system tray
    is enabled. Both were causing first shutdown/logout attempt
    to abort. Not anymore, hopefully ;).
  - Make sure all activated patchbay definition files are in
    their complete and absolute directory path forms.
  - Connections refresh button now does an immediate and true
    reconstruction of all clients and their respective ports
    and connections, unconditionally.
  - Command line server start option (-s, --start) is now made
    independent from configuration setup option (cf. Setup/Misc
    /Start JACK audio server on application startup).
  - Now handling cable socket types properly to let patchbay
    definitions work correctly, whenever having sockets with
    the very same literal name (twisted from patch #3183467,
    by Karsten, thanks;).
  - Abrupt focus behavior when any of the keyboard modifiers
    (Shift, Ctrl, Alt, Caps Lock) is hit while on Connections
    client/port aliases editing (rename) has been fixed.
  - Russian (ru) translation updated (by Alexandre Prokoudine).
  - Added include "errno.h" alegedly missing for BSD style
    systems (applying patch for bug #3126091).
* Wed Dec  1 2010 mseben@gmail.com
- updated to 0.3.7:
  - Session widget has session save type preserved as well.
  - Connections and the new Messages/Status widgets now have
    their last open tab preserved across program run-cycles.
  - Connections and Patchbay widgets have been finally given
    up on an old feature request: an Expand All items button.
  - The Messages and Status widgets were merged into one,
    giving space to the new Session wigdet
  - libX11 is now being added explicitly to the build link
    phase
  - Input/Output latency options were missing but now finally
    enabled for the firewire back-end.
  - General standard dialog buttons layout is now in place.
  - Avoid pre-loading a stalled patchbay definition filename
    and its nagging error on startup (fixes bug #3017078).
  - Client connection retrial logic scrapped. Being a leftover
    from early ages, when machines were slower and JACK server
    startup times were longer... now, if it can't connect first
    time as client, it will tear down the server whether it's
    starting up still or not at all. (cf. Setup/Settings/Start
    Delay for the rescue).
  - Server name is finally part of the server settings presets,
    thanks to Fons Adriaensen for the heads-up.
  - As a workaround regarding issues switching jack2's backends,
    Robin Gareus sends us yet another D-Bus metho slot: "preset",
    (dbus-send --system / org.rncbc.qjackctl.preset string:PRESET).
    Thanks again.
  - Another D-Bus interface slot makes it through implementation:
    "quit" (eg. usage: dbus-send --system / org.rncbc.qjackctl.quit).
    Besides, there's also these new JACK session management actions
    which were being overlooked as well: "load", "save", "savequit"
    and "savetemplate" are also available as D-Bus method slots.
  - Make sure that Patchbay socket names are unique when adding
    or copying, fixing previous patch by Dominic Sacre.
  - JACK version is now being shown on the About box (jack2).
  - Slight Connections widget behavioral change: (dis)connecting a
    client (from) to one single port, (dis)connections will be
    applied in sequence from (to) all client output ports to (from)
    as many input ports there are in below, one by one (satisfying
    a 5 year old request from Yann Orlarey, thanks:).
  - JACK session support is being introduced.
  - Ignore first XRUN occurrence option dropped from statistics.
  - Initial widget geometry and visibility persistence logic has
    been slightly revised as much to avoid crash failures due to
    wrong main widget hidden state.
  - Double-quotes are now being added to device names which include
    blank characters and were rendering invalid all command line
    invocation of the classic JACK server (eg. specially due for
    Portaudio device names on Windows).
  - Transport play (rolling) status is now being guarded to avoid
    backfiring from extraneous transport state changes.
  - General source tree layout and build configuration change.
  - Italian (it) translation added (by Sergio Atzori).
  - Post-shutdown script invocation logic slightly refactored in
    attempt to enforce its execution on application quit.
- deprecated translation-folder.diff
* Wed Apr  7 2010 davejplater@gmail.com
- Updated to 0.3.6: now has full D-Busification!
- Fix patch qjackctl-translation-folder.diff
- Make sure socket names are unique on each side of the Patchbay
- A bunch of primitive D-Bus interface slots have been added,
- Patchbay snapshot now tolerates JACK client port strings that
  have more than one semi-colon in it.
- Most modal message dialog boxes (eg. critical errors) are now
  replaced by system tray icon bubble messages where available
- Comply with jackd >= 0.118.0 which now runs in real-time mode by
  default; use of -R is now deprecated from the jackd command line
  interface options; use -r to run in non-real-time-scheduling.
- A man page has beed added.
- Got rid of a pretty old and never really useful "jackd-realtime"
  server path option.
- D-Bus support, as provided by org.jackaudio.service aka jackdbus,
  is now being introduced and used wherever available and whenever
  enabled.
- Server name command line option added (-n, --server-name).
- Single application instance restriction option added (X11).
- Setup for the netjack (slave) "net" driver has now sample-rate
  and frames per buffer (period size) settings disabled and/or
  ignored, as those are pretty much auto-detected by default;
  also, a new "netone" backend driver option has been introduced
- Czech (cs) translation added (by Pavel Fric).
- Fixed glitch on configure portaudio support, specially when the
  library is not detected as available. See changelog for more.
* Mon Nov 16 2009 mseben@novell.com
- updated to 0.3.5:
  * Late support for UTF-8 encoded client/port names.
  * Allow only one single patchbay connection to or from an
    exclusive socket.
  * Automatic crash-dump reports, debugger stack-traces (gdb),
    back-traces, whatever, are being introduced as a brand new configure
    option (--enable-stacktrace) and default enabled on debug build
    targets (--enable-debug).
  * Probable fix on the audio connections with regard to client/port
    (re)name changes (an ancient bug reported by Fons Adriaensen).
  * Portaudio device selector is now available (after a patch
    handed by Torben Hohn and Stephane Letz).
  * A couple of primitive D-Bus interface slots have been introduced,
    giving the option to start/stop the jackd server from the system
    bus eg. via dbus-send --system / org.rncbc.qjackctl.start (.stop),
    (a nice addition supplied by Robin Gareus, thanks).
  * New command line option (-a, --active-patchbay=path) to specify and
    activate a given patchbay definition file (a simple patch sent by
    John Schneiderman, thanks).
  * Added one significant digit to DSP Load percentage status display.
  * Tentative support for netjack (slave) by adding the "net" driver to
    the existing backend driver options on the Setup/Settings section.
  * Converted obsolete QMessageBox forms to standard buttons.
  * New patchbay snapshot now raises the dirty flag and allows for
    the immediate salvage of patchbay definition profile.
  * Conditional build for JACK port aliases support (JACK >= 0.109.2).
  * Alternate icon sizes other than default 16x16, are now effective to
    the Connections widget (Setup/Dislay/Connections Window/Icon size).
* Mon Aug 31 2009 mseben@suse.cz
- added jack to Requires section
* Tue Dec  9 2008 tiwai@suse.de
- updated to version 0.3.4:
  * Translations in-package
  * The rewrite of old patchbay snapshot feature
  * On Setup/Settings/Parameters dialog, all device selection
    options are now reset to default when disabled interactively.
  * Grayed/disabled palette color group fix for dark color themes.
  * Qt Software logo update.
  * Fait-divers: desktop menu file touched to openSUSE conventions.
  * ALSA PCM devices now only listed/enumerated iif strictly
    compliant with the audio mode criteria
  * JACK client/port aliases may now be displayed as a global user
    option (see Setup/Display/Connections/JACK client/port aliases).
  * Lighten up the connections line and highlight colors, as seen
    to fit best on some darker background themes.
  * Patchbay snapshot fixed to differentiate socket clients
    according to its type (Audio, MIDI or ALSA-Seq).
  * JACK_DEFAULT_SERVER environment variable is now appended to the
    X11 unique application identifier, allowing for having multiple
    instances each controlling its own JACK server.
  * Due to some trouble with newer Qt >= 4.4 applications regarding
    font size configuration, a new global user option is now
    available to the rescue: Setup/Misc/Defaults/Base font size
- moved translation path from locale directory to its own one,
  as build doesn't accept it (yet).
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 0.3.3:
  * load Qt's own translation support and get rid of the ever
    warning startup message
  * Messages file logging makes its first long overdue appearance
  * Only one application instance is now allowed
  * Full JACK MIDI support sneaks into the patchbay
  * Sun driver support
  * Delay window positioning at startup option is now being
    disabled
  * Cosmetic fix for apperance
* Fri Dec 21 2007 tiwai@suse.de
- updated to version 0.3.2:
  * Patchbay port matching has been slightly extended
  * Start option from Setup/Misc/Start
  * Regression from QSystemTrayIcon (Qt4 >= 4.2) implementation
  * Some portaudio backend settings are now being enabled
  * Server mode display blinking (RT indicator) is now an option
  * Tool/child windows position and size preservation fixed.
  * The connections/patchbay auto-refresh option has been removed
  * Messages line limit was not being checked, now honored.
  * Patchbay snapshot got its socket and port ordering back.
  * ALSA Sequencer support is now an optional feature on setup
  * Get configure to try and detect the correct qmake location
  * The connections widget is now being properly refreshed
  * The xrun count stats can now be reset simply by middle clicking
    on the systray icon or the main window's display area
  * An improved version of the "shiny" background image was issued
  * A warning is now being issued, asking whether one wants to
    remove a corresponding Patchbay connection, etc
  * The infamous "Keep child windows always on top" global option
    is now supposed to behave a little better
  * Input/Output Channel setting is allowed to be greater than 32
* Thu Jul 19 2007 tiwai@suse.de
- updated to version 0.3.1a:
  * system-tray icon tooltip shows the current DSP load
  * fixed Connections/Patchbay item tooltip crash bug
  * use QSystemTrayIcon class facility if available
  * refactoring QProcess class usage
  * A new eye-candy bit has sneaked in
  * Combo-box setup history has been corrected on restore
* Wed Jul 11 2007 tiwai@suse.de
- updated to version 0.3.0:
  * Qt4 migration
* Tue Jul  3 2007 tiwai@suse.de
- updated to version 0.2.23:
  * JACK MIDI support is now being introduced
  * Application icon is now installed to ${prefix}/share/pixmaps
  * Invalidation of the JACK client handle is now forced right on
    jack_shutdown notification
  * Default font option names were adjusted to "Sans Serif" and
    "Monospace"
  * The "keep child windows always on top" option is not set as
    default anymore
  * Autoconf (configure) scripting gets an update.
* Mon Apr  2 2007 tiwai@suse.de
- updated to version 0.2.22:
  * Fixed default settings for the freebob backend (JACK >=
    0.103.0).
  * CPU Load status label now says correctly DSP Load.
  * The most recently used patchbay definitions can now be
    correctly selected in round-robin fashion from its drop-down
    list widget.
  * Avoid mixing JACK MIDI ports with regular audio ports on the
    Connections and Patchbay widgets; strictly list only audio
    ports.
  * Added 192k sample rate to setup settings drop down list (as
    kindly reminded by Klaus Zimmermann, thanks).
  * Most top-level widgets were missing the normal-widget flag,
    which were causing some sticky size behavior on some window
    managers.
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 0.2.21:
  * GPL address update
  * All window captions can now be set smaller as tool-widgets
  * The main window button text labels are now optional
  * Increased the default maximum number of ports setting from 128 to 256.
  * Initial freebob backend driver support
  * Quit the whole app when closing the main window
  * Rewind, Play and Pause transport commands are on main pop-up menu
  * Call post-shutdown script when using the Stop button
  * The main window buttons display are now optional
  * Added configure support for x86_64 libraries
* Mon May 15 2006 tiwai@suse.de
- updated to version 0.2.20.
  * new cmdline option for server path
  * improved patchbay dialog
  * improved XRUN callback notification
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 tiwai@suse.de
- updated to 0.2.19a.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Oct 12 2005 tiwai@suse.de
- fix for qt3.3.5 (remove invalid includehints)
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 0.2.18.
* Wed Feb  9 2005 tiwai@suse.de
- updated to version 0.2.15a.
* Tue Feb  8 2005 tiwai@suse.de
- updated to version 0.2.15.
* Mon Jan 24 2005 tiwai@suse.de
- updated to version 0.2.14.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.2.13.
* Fri Jan  7 2005 adrian@suse.de
- fix build, qmake isn't in default $PATH anymore
* Wed Sep 22 2004 mskibbe@suse.de
- change specfile (suse_update_desktop_file)
* Mon Sep  6 2004 tiwai@suse.de
- updated to version 0.2.10.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.2.9.
* Mon Jun 14 2004 mana@suse.de
- update to version 0.2.8
* Mon Mar  1 2004 tiwai@suse.de
- updated to version 0.2.6.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 0.2.5.
- build as non-root.
* Mon Jan 19 2004 tiwai@suse.de
- updated to version 0.2.3a.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 0.1.2.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Tue Sep  2 2003 tiwai@suse.de
- changed the default configuration for suse distro.
* Mon Sep  1 2003 tiwai@suse.de
- merge 0.0.4 updates.
  minor bugfixes only.
* Sun Aug 17 2003 adrian@suse.de
- justify Category
* Thu Aug 14 2003 tiwai@suse.de
- initial version: 0.0.3.
